@@ -1,21 +1,21 @@
-#' Method that runs the fanny algorithm using the euclidean metric to make an external or internal validation of the cluster
+#' Method that runs the fanny algorithm using the euclidean metric to make an external or internal validation of the cluster.
 #'
-#' @param data matrix or data frame
-#' @param clusters number of clusters
-#' @param columnClass number of column, for example if a dataset has five column,
-#' we can select column four to calculate alidation
-#' @param metric metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
+#' @param dt matrix or data frame with the set of values to be applied to the algorithm.
+#' @param clusters is an integer that indexes the number of clusters we want to create.
+#' @param columnClass is an integer with the number of columns, for example if a dataset has five column,
+#' we can select column four to calculate alidation.
+#' @param metric is a characters vector with the metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
 #'
-#' @return returns a list with both the internal and external evaluation of the grouping
+#' @return returns a list with both the internal and external evaluation of the grouping.
 #'
 #' @keywords internal
 #'
 
-fanny_euclidean_method = function(data, clusters, columnClass, metric) {
+fanny_euclidean_method = function(dt, clusters, columnClass, metric) {
   start.time <- Sys.time()
 
-  if ('data.frame' %in% class(data))
-    data = as.matrix(data)
+  if ('data.frame' %in% class(dt))
+    dt = as.matrix(dt)
 
   numeric_cluster <- ifelse(!is.numeric(clusters),1,0)
 
@@ -24,7 +24,7 @@ fanny_euclidean_method = function(data, clusters, columnClass, metric) {
 
   fanny_euclidean <- tryCatch({
     fanny(
-      x = data,
+      x = dt,
       k = clusters,
       metric = CONST_EUCLIDEAN,
       maxit = 100,
@@ -39,7 +39,7 @@ fanny_euclidean_method = function(data, clusters, columnClass, metric) {
   if (!is.null(fanny_euclidean)) {
     ev_fanny_euclidean <-
       tryCatch({
-        external_validation(c(data[, columnClass]),
+        external_validation(c(dt[, columnClass]),
                             fanny_euclidean$clustering,metric)
 
       },
@@ -52,7 +52,7 @@ fanny_euclidean_method = function(data, clusters, columnClass, metric) {
       internal_validation(
         distance = as.vector(fanny_euclidean$diss),
         clusters_vector = fanny_euclidean$clustering,
-        data = data,
+        dataf = dt,
         method = CONST_EUCLIDEAN,
         metric
       )
@@ -81,24 +81,24 @@ fanny_euclidean_method = function(data, clusters, columnClass, metric) {
   return (result)
 }
 
-#' Method that runs the fanny algorithm using the manhattan metric to make an external or internal validation of the cluster
+#' Method that runs the fanny algorithm using the manhattan metric to make an external or internal validation of the cluster.
 #'
-#' @param data matrix or data frame
-#' @param clusters number of clusters
-#' @param columnClass number of column, for example if a dataset has five column,
-#' we can select column four to calculate alidation
-#' @param metric metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
+#' @param dt matrix or data frame with the set of values to be applied to the algorithm..
+#' @param clusters is an integer that indexes the number of clusters we want to create.
+#' @param columnClass is an integer with the number of columns, for example if a dataset has five column,
+#' we can select column four to calculate alidation.
+#' @param metric is a characters vector with the metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
 #'
-#' @return returns a list with both the internal and external evaluation of the grouping
+#' @return returns a list with both the internal and external evaluation of the grouping.
 #'
 #' @keywords internal
 #'
 
-fanny_manhattan_method = function(data, clusters, columnClass, metric) {
+fanny_manhattan_method = function(dt, clusters, columnClass, metric) {
   start.time <- Sys.time()
 
-  if ('data.frame' %in% class(data))
-    data = as.matrix(data)
+  if ('data.frame' %in% class(dt))
+    dt = as.matrix(dt)
 
   numeric_cluster <- ifelse(!is.numeric(clusters),1,0)
 
@@ -107,7 +107,7 @@ fanny_manhattan_method = function(data, clusters, columnClass, metric) {
 
   fanny_manhattan <- tryCatch({
     fanny(
-      x = data,
+      x = dt,
       k = clusters,
       metric = CONST_MANHATTAN,
       maxit = 100,
@@ -122,7 +122,7 @@ fanny_manhattan_method = function(data, clusters, columnClass, metric) {
   if (!is.null(fanny_manhattan)) {
     ev_fanny_manhattan <-
       tryCatch({
-        external_validation(c(data[, columnClass]),
+        external_validation(c(dt[, columnClass]),
                             fanny_manhattan$clustering,metric)
 
       },
@@ -135,7 +135,7 @@ fanny_manhattan_method = function(data, clusters, columnClass, metric) {
       internal_validation(
         distance = as.vector(fanny_manhattan$diss),
         clusters_vector = fanny_manhattan$clustering,
-        data = data,
+        dataf = dt,
         method = CONST_MANHATTAN,
         metric
       )
