@@ -1,21 +1,21 @@
-#' Method that runs the pvclust algorithm using the Euclidean metric to make an external or internal validation of the cluster
+#' Method that runs the pvclust algorithm using the Euclidean metric to make an external or internal validation of the cluster.
 #'
-#' @param data matrix or data frame
-#' @param clusters number of clusters
-#' @param columnClass number of column, for example if a dataset has five column,
-#' we can select column four to calculate alidation
-#' @param metric metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
+#' @param dt matrix or data frame with the set of values to be applied to the algorithm.
+#' @param clusters is an integer that indexes the number of clusters we want to create.
+#' @param columnClass is an integer with the number of columns, for example if a dataset has five column,
+#' we can select column four to calculate alidation.
+#' @param metric is a characters vector with the metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
 #'
-#' @return returns a list with both the internal and external evaluation of the grouping
+#' @return returns a list with both the internal and external evaluation of the grouping.
 #'
 #' @keywords internal
 #'
 
-pvclust_euclidean_method = function(data, clusters, columnClass, metric) {
+pvclust_euclidean_method = function(dt, clusters, columnClass, metric) {
   start.time <- Sys.time()
 
-  if ('data.frame' %in% class(data))
-    data = as.matrix(data)
+  if ('data.frame' %in% class(dt))
+    dt = as.matrix(dt)
 
   numeric_cluster <- ifelse(!is.numeric(clusters),1,0)
 
@@ -23,7 +23,7 @@ pvclust_euclidean_method = function(data, clusters, columnClass, metric) {
     stop('The field clusters must be a numeric')
 
   pvclust_euclidean <- tryCatch({
-    pvclust(data = data, method.dist = CONST_EUCLIDEAN)
+    pvclust(data = dt, method.dist = CONST_EUCLIDEAN)
   },
 
   error = function(cond) {
@@ -46,7 +46,7 @@ pvclust_euclidean_method = function(data, clusters, columnClass, metric) {
       internal_validation(
         distance = NULL,
         clusters_vector = cutree(pvclust_euclidean$hclust, k = clusters),
-        data = data,
+        dataf = dt,
         method = CONST_EUCLIDEAN,
         metric
       )
@@ -75,24 +75,24 @@ pvclust_euclidean_method = function(data, clusters, columnClass, metric) {
 }
 
 
-#' Method that runs the pvclust algorithm using the Correlation metric to make an external or internal validation of the cluster
+#' Method that runs the pvclust algorithm using the Correlation metric to make an external or internal validation of the cluster.
 #'
-#' @param data matrix or data frame
-#' @param clusters number of clusters
-#' @param columnClass number of column, for example if a dataset has five column,
-#' we can select column four to calculate alidation
-#' @param metric metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
+#' @param dt matrix or data frame with the set of values to be applied to the algorithm.
+#' @param clusters is an integer that indexes the number of clusters we want to create.
+#' @param columnClass is an integer with the number of columns, for example if a dataset has five column,
+#' we can select column four to calculate alidation.
+#' @param metric is a characters vector with the metrics avalaible in the package. The metrics implemented are: entropy, variation_information,precision,recall,f_measure,fowlkes_mallows_index,connectivity,dunn,silhouette.
 #'
-#' @return returns a list with both the internal and external evaluation of the grouping
+#' @return returns a list with both the internal and external evaluation of the grouping.
 #'
 #' @keywords internal
 #'
 
-pvclust_correlation_method = function(data, clusters, columnClass, metric) {
+pvclust_correlation_method = function(dt, clusters, columnClass, metric) {
   start.time <- Sys.time()
 
-  if ('data.frame' %in% class(data))
-    data = as.matrix(data)
+  if ('data.frame' %in% class(dt))
+    dt = as.matrix(dt)
 
   numeric_cluster <- ifelse(!is.numeric(clusters),1,0)
 
@@ -100,7 +100,7 @@ pvclust_correlation_method = function(data, clusters, columnClass, metric) {
     stop('The field clusters must be a numeric')
 
   pvclust_correlation <- tryCatch({
-    pvclust(data = data, method.dist = CONST_CORRELATION)
+    pvclust(data = dt, method.dist = CONST_CORRELATION)
   },
 
   error = function(cond) {
@@ -122,7 +122,7 @@ pvclust_correlation_method = function(data, clusters, columnClass, metric) {
       internal_validation(
         distance = NULL,
         clusters_vector = cutree(pvclust_correlation$hclust, k = clusters),
-        data = data,
+        dataf = dt,
         method = CONST_PEARSON_CORRELATION,
         metric
       )
